@@ -222,21 +222,10 @@ cleanso <- function(x,where=soloc(x)) {
 ##' 
 ##' @export
 ##' @keywords internal
-touch_funs <- function(x,keep_pointers=TRUE) {
-  
+touch_funs <- function(x, keep_pointers = TRUE) {
   funp <- pointers(x)
-  
-  param <- as.numeric(param(x))
-  init <- as.numeric(x@init)
-  neta <- sum(nrow(omat(x)))
-  neps <- sum(nrow(smat(x)))
-  
-  out <- .Call(`_mrgsolve_TOUCH_FUNS`,param,init,
-               neta,neps,x@capture,funp,
-               x@envir, PACKAGE = "mrgsolve")
-  
-  names(out$init) <- names(init)
-  
+  out <- .Call(`_mrgsolve_TOUCH_FUNS`, funp, x, PACKAGE = "mrgsolve")
+  names(out$init) <- Cmt(x)
   if(keep_pointers) {
     out[["pointers"]] <- funp
   }
