@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2020  Metrum Research Group
+# Copyright (C) 2013 - 2021  Metrum Research Group
 #
 # This file is part of mrgsolve.
 #
@@ -55,7 +55,8 @@
 ##' mod <- mread("viral2", modlib())
 ##' mod <- mread("pred1",  modlib())
 ##' mod <- mread("pbpk",   modlib())
-##' mod <- mread("1005",   modlib()) # embedded NONMEM result
+##' mod <- mread("1005",   modlib())      # embedded NONMEM result
+##' mod <- mread("nm-like", modlib()) # model with nonmem-like syntax
 ##' 
 ##' mrgsolve:::code(mod)
 ##' }
@@ -74,7 +75,7 @@ modlib <- function(model = NULL,...,list=FALSE)  {
 modlib_models <- c(
   "pk1cmt", "pk2cmt", "pk3cmt", "pk", "pk1", "pk2", "popex",
   "irm1", "irm2", "irm3", "pred1", "emax", "tmdd", "viral1", 
-  "viral2", "effect", "1005"
+  "viral2", "effect", "1005", "nm-like"
 )
 #nocov end
 
@@ -303,9 +304,19 @@ NULL
 
 ##' Extract the code from a model
 ##' 
-##' @param x an mrgsolve model object
-##' @return a character vector of model code
+##' This function is currently not exported, so be sure to call it with 
+##' `mrgsolve:::code(...)`.
 ##' 
+##' @param x an mrgsolve model object
+##' 
+##' @examples
+##' mod <- mrgsolve::house()
+##' mrgsolve:::code(mod)
+##' 
+##' @return 
+##' A character vector of model code.
+##' 
+##' @md
 code <- function(x) {
   stopifnot(is.mrgmod(x))
   what <- try(x@code, silent=TRUE)
@@ -315,4 +326,3 @@ code <- function(x) {
   }
   return(what)
 }
-
