@@ -1,4 +1,4 @@
-// Copyright (C) 2013 - 2019  Metrum Research Group
+// Copyright (C) 2013 - 2022  Metrum Research Group
 //
 // This file is part of mrgsolve.
 //
@@ -42,21 +42,18 @@
  *
  */
 
-
-
 #include "RcppInclude.h"
 #include "mrgsolv.h"
 
-
 #define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}
 
 RcppExport SEXP _mrgsolve_dcorr(SEXP);
 RcppExport SEXP _mrgsolve_get_tokens(SEXP);
 RcppExport SEXP _mrgsolve_MVGAUSS(SEXP,SEXP);
-RcppExport SEXP _mrgsolve_DEVTRAN(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,
-                                  SEXP,SEXP,SEXP,SEXP);
+RcppExport SEXP _mrgsolve_DEVTRAN(SEXP,SEXP,SEXP,SEXP,SEXP);
 RcppExport SEXP _mrgsolve_SUPERMATRIX(SEXP,SEXP);
-RcppExport SEXP _mrgsolve_TOUCH_FUNS(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
+RcppExport SEXP _mrgsolve_MAKEMATRIX(SEXP);
+RcppExport SEXP _mrgsolve_TOUCH_FUNS(SEXP,SEXP);
 RcppExport SEXP _mrgsolve_EXPAND_EVENTS(SEXP,SEXP,SEXP);
 RcppExport SEXP _mrgsolve_EXPAND_OBSERVATIONS(SEXP,SEXP,SEXP,SEXP);
 
@@ -68,9 +65,10 @@ RcppExport void _model_housemodel_config__(MRGSOLVE_CONFIG_SIGNATURE);
 static R_CallMethodDef callEntryPoints[]  = {
   CALLDEF(_mrgsolve_get_tokens,1),
   CALLDEF(_mrgsolve_MVGAUSS,2),
-  CALLDEF(_mrgsolve_DEVTRAN,12),
+  CALLDEF(_mrgsolve_DEVTRAN,5),
   CALLDEF(_mrgsolve_SUPERMATRIX,2),
-  CALLDEF(_mrgsolve_TOUCH_FUNS,7),
+  CALLDEF(_mrgsolve_MAKEMATRIX,1),
+  CALLDEF(_mrgsolve_TOUCH_FUNS,2),
   CALLDEF(_mrgsolve_EXPAND_EVENTS,3),
   CALLDEF(_mrgsolve_EXPAND_OBSERVATIONS,4),
   CALLDEF(_mrgsolve_dcorr,1),
